# Generated by Django 2.2.7 on 2019-12-05 17:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0007_userorder_time_of_order'),
    ]

    operations = [
        migrations.AddField(
            model_name='userorder',
            name='booked',
            field=models.BooleanField(default=True),
            preserve_default=False,
        ),
    ]
